@@ -14,7 +14,7 @@ test_that("constellation() define constellation", {
     db2 <- star_database(mrs_age_schema, ft2) |>
       snake_case()
 
-    ct <- constellation("MRS", list(db1, db2))
+    ct <- constellation("MRS", db1, db2)
   }, {
     structure(
       list(
@@ -23,55 +23,84 @@ test_that("constellation() define constellation", {
           mrs_cause = structure(list(
             operations = structure(
               list(
-                operation = c(
-                  "define_dimension",
-                  "define_dimension",
-                  "define_facts",
-                  "snake_case"
-                ),
-                name = c("When",
-                         "Where", "MRS Cause", ""),
-                details = c(
-                  "Year",
-                  "REGION<|>State<|>City",
-                  "Pneumonia and Influenza Deaths<|>All Deaths<|>nrow_agg",
-                  ""
-                ),
-                details2 = c("", "", "SUM<|>SUM<|>SUM", ""),
-                order = c(1,
-                          2, 3, 4)
+                operation = c("star_database",
+                              "snake_case"),
+                name = c("mrs_cause", ""),
+                details = c("___UNKNOWN___",
+                            ""),
+                details2 = c("", ""),
+                order = c(1, 2)
               ),
-              row.names = c(NA,-4L),
+              row.names = c(NA,-2L),
               class = "data.frame"
             )
           ), class = "star_operation"),
           mrs_age = structure(list(
             operations = structure(
               list(
-                operation = c(
-                  "define_dimension",
-                  "define_dimension",
-                  "define_dimension",
-                  "define_facts",
-                  "snake_case"
-                ),
-                name = c("When", "Where", "Who", "MRS Age", ""),
-                details = c(
-                  "Year",
-                  "REGION<|>State<|>City",
-                  "Age",
-                  "All Deaths<|>nrow_agg",
-                  ""
-                ),
-                details2 = c("", "", "", "SUM<|>SUM", ""),
-                order = c(1,
-                          2, 3, 4, 5)
+                operation = c("star_database",
+                              "snake_case"),
+                name = c("mrs_age", ""),
+                details = c("___UNKNOWN___",
+                            ""),
+                details2 = c("", ""),
+                order = c(1, 2)
               ),
-              row.names = c(NA,-5L),
+              row.names = c(NA,-2L),
               class = "data.frame"
             )
           ), class = "star_operation")
         ),
+        lookup_tables = list(mrs_cause = NULL, mrs_age = NULL),
+        schemas = list(
+          mrs_cause = structure(list(
+            facts = list(mrs_cause = structure(
+              list(
+                name = "MRS Cause",
+                measures = c("Pneumonia and Influenza Deaths",
+                             "All Deaths"),
+                agg_functions = NULL,
+                nrow_agg = NULL
+              ),
+              class = "fact_schema"
+            )),
+            dimensions = list(
+              when = structure(list(
+                name = "When",
+                attributes = "Year"
+              ), class = "dimension_schema"),
+              where = structure(list(
+                name = "Where",
+                attributes = c("REGION",
+                               "State", "City")
+              ), class = "dimension_schema")
+            )
+          ), class = "star_schema"),
+          mrs_age = structure(list(
+            facts = list(mrs_age = structure(
+              list(
+                name = "MRS Age",
+                measures = "All Deaths",
+                agg_functions = NULL,
+                nrow_agg = NULL
+              ),
+              class = "fact_schema"
+            )),
+            dimensions = list(
+              when = structure(list(
+                name = "When", attributes = "Year"
+              ), class = "dimension_schema"),
+              where = structure(list(
+                name = "Where",
+                attributes = c("REGION",
+                               "State", "City")
+              ), class = "dimension_schema"),
+              who = structure(list(
+                name = "Who", attributes = "Age"
+              ), class = "dimension_schema")
+            )
+          ), class = "star_schema")
+        ),
         facts = list(
           mrs_cause = structure(
             list(
@@ -94,7 +123,7 @@ test_that("constellation() define constellation", {
                                  46L, 192L, 276L),
                   nrow_agg = c(3L, 2L, 2L, 1L, 3L, 1L)
                 ),
-                row.names = c(NA, -6L),
+                row.names = c(NA,-6L),
                 class = c("tbl_df", "tbl",
                           "data.frame")
               )
@@ -121,7 +150,7 @@ test_that("constellation() define constellation", {
                   nrow_agg = c(3L, 3L,
                                3L, 3L, 3L, 1L, 1L, 1L, 1L, 1L, 3L, 3L, 3L, 3L, 3L)
                 ),
-                row.names = c(NA, -15L),
+                row.names = c(NA,-15L),
                 class = c("tbl_df", "tbl", "data.frame")
               )
             ),
@@ -139,7 +168,7 @@ test_that("constellation() define constellation", {
                   year = c("1962",
                            "1963", "1964")
                 ),
-                row.names = c(NA, -3L),
+                row.names = c(NA,-3L),
                 class = c("tbl_df",
                           "tbl", "data.frame")
               )
@@ -158,7 +187,7 @@ test_that("constellation() define constellation", {
                   city = c("Bridgeport",
                            "Hartford", "Boston", "Cambridge")
                 ),
-                row.names = c(NA, -4L),
+                row.names = c(NA,-4L),
                 class = c("tbl_df", "tbl", "data.frame")
               )
             ),
@@ -179,7 +208,7 @@ test_that("constellation() define constellation", {
                     "<1 year"
                   )
                 ),
-                row.names = c(NA, -5L),
+                row.names = c(NA,-5L),
                 class = c("tbl_df", "tbl",
                           "data.frame")
               )
@@ -223,7 +252,7 @@ test_that("constellation() define constellation", {
     db3 <- star_database(s, ft_num) |>
       snake_case()
 
-    ct <- constellation("MRS", list(db1, db2, db3))
+    ct <- constellation("MRS", db1, db2, db3)
   }, {
     structure(
       list(
@@ -232,76 +261,124 @@ test_that("constellation() define constellation", {
           mrs_cause = structure(list(
             operations = structure(
               list(
-                operation = c(
-                  "define_dimension",
-                  "define_dimension",
-                  "define_facts",
-                  "snake_case"
-                ),
-                name = c("When",
-                         "Where", "MRS Cause", ""),
-                details = c(
-                  "Year",
-                  "REGION<|>State<|>City",
-                  "Pneumonia and Influenza Deaths<|>All Deaths<|>nrow_agg",
-                  ""
-                ),
-                details2 = c("", "", "SUM<|>SUM<|>SUM", ""),
-                order = c(1,
-                          2, 3, 4)
+                operation = c("star_database",
+                              "snake_case"),
+                name = c("mrs_cause", ""),
+                details = c("___UNKNOWN___",
+                            ""),
+                details2 = c("", ""),
+                order = c(1, 2)
               ),
-              row.names = c(NA,-4L),
+              row.names = c(NA,-2L),
               class = "data.frame"
             )
           ), class = "star_operation"),
           mrs_age = structure(list(
             operations = structure(
               list(
-                operation = c(
-                  "define_dimension",
-                  "define_dimension",
-                  "define_dimension",
-                  "define_facts",
-                  "snake_case"
-                ),
-                name = c("When", "Where", "Who", "MRS Age", ""),
-                details = c(
-                  "Year",
-                  "REGION<|>State<|>City",
-                  "Age",
-                  "All Deaths<|>nrow_agg",
-                  ""
-                ),
-                details2 = c("", "", "", "SUM<|>SUM", ""),
-                order = c(1,
-                          2, 3, 4, 5)
+                operation = c("star_database",
+                              "snake_case"),
+                name = c("mrs_age", ""),
+                details = c("___UNKNOWN___",
+                            ""),
+                details2 = c("", ""),
+                order = c(1, 2)
               ),
-              row.names = c(NA,-5L),
+              row.names = c(NA,-2L),
               class = "data.frame"
             )
           ), class = "star_operation"),
           mrs_cause_2 = structure(list(
             operations = structure(
               list(
-                operation = c(
-                  "define_dimension",
-                  "define_dimension",
-                  "define_facts",
-                  "snake_case"
-                ),
-                name = c("When", "Where",
-                         "MRS Cause 2", ""),
-                details = c("Year", "REGION<|>City<|>State",
-                            "nrow_agg", ""),
-                details2 = c("", "", "SUM", ""),
-                order = c(1,
-                          2, 3, 4)
+                operation = c("star_database", "snake_case"),
+                name = c("mrs_cause_2",
+                         ""),
+                details = c("___UNKNOWN___", ""),
+                details2 = c("",
+                             ""),
+                order = c(1, 2)
               ),
-              row.names = c(NA,-4L),
+              row.names = c(NA,-2L),
               class = "data.frame"
             )
           ), class = "star_operation")
         ),
+        lookup_tables = list(
+          mrs_cause = NULL,
+          mrs_age = NULL,
+          mrs_cause_2 = NULL
+        ),
+        schemas = list(
+          mrs_cause = structure(list(
+            facts = list(mrs_cause = structure(
+              list(
+                name = "MRS Cause",
+                measures = c("Pneumonia and Influenza Deaths",
+                             "All Deaths"),
+                agg_functions = NULL,
+                nrow_agg = NULL
+              ),
+              class = "fact_schema"
+            )),
+            dimensions = list(
+              when = structure(list(
+                name = "When",
+                attributes = "Year"
+              ), class = "dimension_schema"),
+              where = structure(list(
+                name = "Where",
+                attributes = c("REGION",
+                               "State", "City")
+              ), class = "dimension_schema")
+            )
+          ), class = "star_schema"),
+          mrs_age = structure(list(
+            facts = list(mrs_age = structure(
+              list(
+                name = "MRS Age",
+                measures = "All Deaths",
+                agg_functions = NULL,
+                nrow_agg = NULL
+              ),
+              class = "fact_schema"
+            )),
+            dimensions = list(
+              when = structure(list(
+                name = "When", attributes = "Year"
+              ), class = "dimension_schema"),
+              where = structure(list(
+                name = "Where",
+                attributes = c("REGION",
+                               "State", "City")
+              ), class = "dimension_schema"),
+              who = structure(list(
+                name = "Who", attributes = "Age"
+              ), class = "dimension_schema")
+            )
+          ), class = "star_schema"),
+          mrs_cause_2 = structure(list(
+            facts = list(mrs_cause_2 = structure(
+              list(
+                name = "MRS Cause 2",
+                measures = NULL,
+                agg_functions = NULL,
+                nrow_agg = NULL
+              ),
+              class = "fact_schema"
+            )),
+            dimensions = list(
+              when = structure(list(
+                name = "When", attributes = "Year"
+              ), class = "dimension_schema"),
+              where = structure(list(
+                name = "Where",
+                attributes = c("REGION",
+                               "City", "State")
+              ), class = "dimension_schema")
+            )
+          ), class = "star_schema")
+        ),
         facts = list(
           mrs_cause = structure(
             list(
@@ -324,7 +401,7 @@ test_that("constellation() define constellation", {
                                  46L, 192L, 276L),
                   nrow_agg = c(3L, 2L, 2L, 1L, 3L, 1L)
                 ),
-                row.names = c(NA, -6L),
+                row.names = c(NA,-6L),
                 class = c("tbl_df", "tbl",
                           "data.frame")
               )
@@ -351,7 +428,7 @@ test_that("constellation() define constellation", {
                   nrow_agg = c(3L, 3L,
                                3L, 3L, 3L, 1L, 1L, 1L, 1L, 1L, 3L, 3L, 3L, 3L, 3L)
                 ),
-                row.names = c(NA, -15L),
+                row.names = c(NA,-15L),
                 class = c("tbl_df", "tbl", "data.frame")
               )
             ),
@@ -373,7 +450,7 @@ test_that("constellation() define constellation", {
                   nrow_agg = c(2L, 3L, 1L, 2L, 1L, 1L, 3L, 2L,
                                1L, 3L, 1L)
                 ),
-                row.names = c(NA, -11L),
+                row.names = c(NA,-11L),
                 class = c("tbl_df",
                           "tbl", "data.frame")
               )
@@ -392,7 +469,7 @@ test_that("constellation() define constellation", {
                   year = c("1962",
                            "1963", "1964")
                 ),
-                row.names = c(NA, -3L),
+                row.names = c(NA,-3L),
                 class = c("tbl_df",
                           "tbl", "data.frame")
               )
@@ -411,7 +488,7 @@ test_that("constellation() define constellation", {
                   city = c("Bridgeport",
                            "Hartford", "Boston", "Cambridge")
                 ),
-                row.names = c(NA, -4L),
+                row.names = c(NA,-4L),
                 class = c("tbl_df", "tbl", "data.frame")
               )
             ),
@@ -432,7 +509,7 @@ test_that("constellation() define constellation", {
                     "<1 year"
                   )
                 ),
-                row.names = c(NA, -5L),
+                row.names = c(NA,-5L),
                 class = c("tbl_df", "tbl", "data.frame")
               )
             ),
@@ -475,8 +552,8 @@ test_that("constellation() define constellation", {
     db3 <- star_database(s, ft1) |>
       snake_case()
 
-    ct <- constellation("MRS", list(db1, db3))
-    constellation("MRS", list(db2, ct))
+    ct <- constellation("MRS", db1, db3)
+    constellation("MRS", db2, ct)
   }, {
     structure(
       list(
@@ -485,76 +562,124 @@ test_that("constellation() define constellation", {
           mrs_age = structure(list(
             operations = structure(
               list(
-                operation = c(
-                  "define_dimension",
-                  "define_dimension",
-                  "define_dimension",
-                  "define_facts",
-                  "snake_case"
-                ),
-                name = c("When", "Where", "Who", "MRS Age", ""),
-                details = c(
-                  "Year",
-                  "REGION<|>State<|>City",
-                  "Age",
-                  "All Deaths<|>nrow_agg",
-                  ""
-                ),
-                details2 = c("", "", "", "SUM<|>SUM", ""),
-                order = c(1,
-                          2, 3, 4, 5)
+                operation = c("star_database",
+                              "snake_case"),
+                name = c("mrs_age", ""),
+                details = c("___UNKNOWN___",
+                            ""),
+                details2 = c("", ""),
+                order = c(1, 2)
               ),
-              row.names = c(NA,-5L),
+              row.names = c(NA,-2L),
               class = "data.frame"
             )
           ), class = "star_operation"),
           mrs_cause = structure(list(
             operations = structure(
               list(
-                operation = c(
-                  "define_dimension",
-                  "define_dimension",
-                  "define_facts",
-                  "snake_case"
-                ),
-                name = c("When",
-                         "Where", "MRS Cause", ""),
-                details = c(
-                  "Year",
-                  "REGION<|>State<|>City",
-                  "Pneumonia and Influenza Deaths<|>All Deaths<|>nrow_agg",
-                  ""
-                ),
-                details2 = c("", "", "SUM<|>SUM<|>SUM", ""),
-                order = c(1,
-                          2, 3, 4)
+                operation = c("star_database",
+                              "snake_case"),
+                name = c("mrs_cause", ""),
+                details = c("___UNKNOWN___",
+                            ""),
+                details2 = c("", ""),
+                order = c(1, 2)
               ),
-              row.names = c(NA,-4L),
+              row.names = c(NA,-2L),
               class = "data.frame"
             )
           ), class = "star_operation"),
           mrs_cause_2 = structure(list(
             operations = structure(
               list(
-                operation = c(
-                  "define_dimension",
-                  "define_dimension",
-                  "define_facts",
-                  "snake_case"
-                ),
-                name = c("When", "Where",
-                         "MRS Cause 2", ""),
-                details = c("Year", "REGION<|>City<|>State",
-                            "nrow_agg", ""),
-                details2 = c("", "", "SUM", ""),
-                order = c(1,
-                          2, 3, 4)
+                operation = c("star_database", "snake_case"),
+                name = c("mrs_cause_2",
+                         ""),
+                details = c("___UNKNOWN___", ""),
+                details2 = c("",
+                             ""),
+                order = c(1, 2)
               ),
-              row.names = c(NA,-4L),
+              row.names = c(NA,-2L),
               class = "data.frame"
             )
           ), class = "star_operation")
         ),
+        lookup_tables = list(
+          mrs_age = NULL,
+          mrs_cause = NULL,
+          mrs_cause_2 = NULL
+        ),
+        schemas = list(
+          mrs_age = structure(list(
+            facts = list(mrs_age = structure(
+              list(
+                name = "MRS Age",
+                measures = "All Deaths",
+                agg_functions = NULL,
+                nrow_agg = NULL
+              ),
+              class = "fact_schema"
+            )),
+            dimensions = list(
+              when = structure(list(
+                name = "When", attributes = "Year"
+              ), class = "dimension_schema"),
+              where = structure(list(
+                name = "Where",
+                attributes = c("REGION",
+                               "State", "City")
+              ), class = "dimension_schema"),
+              who = structure(list(
+                name = "Who", attributes = "Age"
+              ), class = "dimension_schema")
+            )
+          ), class = "star_schema"),
+          mrs_cause = structure(list(
+            facts = list(mrs_cause = structure(
+              list(
+                name = "MRS Cause",
+                measures = c("Pneumonia and Influenza Deaths",
+                             "All Deaths"),
+                agg_functions = NULL,
+                nrow_agg = NULL
+              ),
+              class = "fact_schema"
+            )),
+            dimensions = list(
+              when = structure(list(
+                name = "When",
+                attributes = "Year"
+              ), class = "dimension_schema"),
+              where = structure(list(
+                name = "Where",
+                attributes = c("REGION",
+                               "State", "City")
+              ), class = "dimension_schema")
+            )
+          ), class = "star_schema"),
+          mrs_cause_2 = structure(list(
+            facts = list(mrs_cause_2 = structure(
+              list(
+                name = "MRS Cause 2",
+                measures = NULL,
+                agg_functions = NULL,
+                nrow_agg = NULL
+              ),
+              class = "fact_schema"
+            )),
+            dimensions = list(
+              when = structure(list(
+                name = "When", attributes = "Year"
+              ), class = "dimension_schema"),
+              where = structure(list(
+                name = "Where",
+                attributes = c("REGION",
+                               "City", "State")
+              ), class = "dimension_schema")
+            )
+          ), class = "star_schema")
+        ),
         facts = list(
           mrs_age = structure(
             list(
@@ -576,7 +701,7 @@ test_that("constellation() define constellation", {
                   nrow_agg = c(3L, 3L,
                                3L, 3L, 3L, 1L, 1L, 1L, 1L, 1L, 3L, 3L, 3L, 3L, 3L)
                 ),
-                row.names = c(NA, -15L),
+                row.names = c(NA,-15L),
                 class = c("tbl_df", "tbl", "data.frame")
               )
             ),
@@ -605,7 +730,7 @@ test_that("constellation() define constellation", {
                                  276L),
                   nrow_agg = c(3L, 2L, 2L, 1L, 3L, 1L)
                 ),
-                row.names = c(NA, -6L),
+                row.names = c(NA,-6L),
                 class = c("tbl_df", "tbl", "data.frame")
               )
             ),
@@ -626,7 +751,7 @@ test_that("constellation() define constellation", {
                   where_key = c(3L, 1L, 2L, 3L, 1L, 2L),
                   nrow_agg = c(2L, 3L, 2L, 1L, 1L, 3L)
                 ),
-                row.names = c(NA, -6L),
+                row.names = c(NA,-6L),
                 class = c("tbl_df", "tbl", "data.frame")
               )
             ),
@@ -644,7 +769,7 @@ test_that("constellation() define constellation", {
                   year = c("1962",
                            "1963", "1964")
                 ),
-                row.names = c(NA, -3L),
+                row.names = c(NA,-3L),
                 class = c("tbl_df",
                           "tbl", "data.frame")
               )
@@ -663,7 +788,7 @@ test_that("constellation() define constellation", {
                   city = c("Bridgeport",
                            "Hartford", "Boston", "Cambridge")
                 ),
-                row.names = c(NA, -4L),
+                row.names = c(NA,-4L),
                 class = c("tbl_df", "tbl", "data.frame")
               )
             ),
@@ -684,7 +809,7 @@ test_that("constellation() define constellation", {
                     "<1 year"
                   )
                 ),
-                row.names = c(NA, -5L),
+                row.names = c(NA,-5L),
                 class = c("tbl_df", "tbl",
                           "data.frame")
               )
@@ -728,8 +853,8 @@ test_that("constellation() define constellation", {
     db3 <- star_database(s, ft1) |>
       snake_case()
 
-    ct <- constellation("MRS", list(db1, db3))
-    constellation("MRS", list(db2, ct))
+    ct <- constellation("MRS", db1, db3)
+    constellation("MRS", db2, ct)
   }, {
     ft1 <- ft_num  |>
       dplyr::filter(City != "Cambridge") |>
@@ -758,8 +883,8 @@ test_that("constellation() define constellation", {
     db3 <- star_database(s, ft1) |>
       snake_case()
 
-    ct <- constellation("MRS", list(db2, db1))
-    constellation("MRS", list(ct, db3))
+    ct <- constellation("MRS", db2, db1)
+    constellation("MRS", ct, db3)
   })
 })
 
@@ -779,7 +904,7 @@ test_that("as_tibble_list() export constellation as a list of tibbles", {
     db2 <- star_database(mrs_age_schema, ft2) |>
       snake_case()
 
-    constellation("MRS", list(db1, db2)) |>
+    constellation("MRS", db1, db2) |>
       as_tibble_list()
   }, {
     list(
@@ -789,7 +914,7 @@ test_that("as_tibble_list() export constellation as a list of tibbles", {
           year = c("1962", "1963",
                    "1964")
         ),
-        row.names = c(NA,-3L),
+        row.names = c(NA, -3L),
         class = c("tbl_df", "tbl",
                   "data.frame")
       ),
@@ -802,7 +927,7 @@ test_that("as_tibble_list() export constellation as a list of tibbles", {
           city = c("Bridgeport",
                    "Hartford", "Boston", "Cambridge")
         ),
-        row.names = c(NA,-4L),
+        row.names = c(NA, -4L),
         class = c("tbl_df",
                   "tbl", "data.frame")
       ),
@@ -817,7 +942,7 @@ test_that("as_tibble_list() export constellation as a list of tibbles", {
             "<1 year"
           )
         ),
-        row.names = c(NA,-5L),
+        row.names = c(NA, -5L),
         class = c("tbl_df", "tbl", "data.frame")
       ),
       mrs_cause = structure(
@@ -831,7 +956,7 @@ test_that("as_tibble_list() export constellation as a list of tibbles", {
                          192L, 276L),
           nrow_agg = c(3L, 2L, 2L, 1L, 3L, 1L)
         ),
-        row.names = c(NA,-6L),
+        row.names = c(NA, -6L),
         class = c("tbl_df", "tbl", "data.frame")
       ),
       mrs_age = structure(
@@ -848,7 +973,7 @@ test_that("as_tibble_list() export constellation as a list of tibbles", {
           nrow_agg = c(3L, 3L, 3L, 3L, 3L, 1L, 1L, 1L, 1L, 1L,
                        3L, 3L, 3L, 3L, 3L)
         ),
-        row.names = c(NA,-15L),
+        row.names = c(NA, -15L),
         class = c("tbl_df",
                   "tbl", "data.frame")
       )
@@ -865,7 +990,7 @@ test_that("constellation() define constellation with rpd", {
     db2 <- star_database(mrs_age_schema_rpd, ft_age_rpd) |>
       role_playing_dimension(rpd = "When Arrived",
                              roles = c("When Available"))
-    db <- constellation("MRS", list(db1, db2))
+    db <- constellation("MRS", db1, db2)
     c(
       db$rpd,
       nrow(db$dimensions$when$table),
@@ -913,7 +1038,7 @@ test_that("constellation() get_role_playing_dimension_names()", {
     db2 <- star_database(mrs_age_schema_rpd, ft_age_rpd) |>
       role_playing_dimension(rpd = "When Arrived",
                              roles = c("When Available"))
-    constellation("MRS", list(db1, db2)) |>
+    constellation("MRS", db1, db2) |>
       get_role_playing_dimension_names()
   }, {
     list(rpd_1 = c("when", "when_arrived", "when_available", "when_received"))
@@ -931,7 +1056,7 @@ test_that("constellation() replace_attribute_values() with role_playing_dimensio
                 star_database(mrs_age_schema_rpd, ft_age_rpd) |>
                 role_playing_dimension(rpd = "When Arrived",
                                        roles = c("When Available"))
-              db <- constellation("MRS", list(db1, db2))
+              db <- constellation("MRS", db1, db2)
               db <- db |> replace_attribute_values(
                 name = "When Available",
                 old = c('1962', '11', '1962-03-14'),
@@ -954,11 +1079,7 @@ test_that("constellation() replace_attribute_values() with role_playing_dimensio
               )
             }, {
               list(
-                "define_dimension",
-                "define_dimension",
-                "define_dimension",
-                "define_dimension",
-                "define_facts",
+                "star_database",
                 "role_playing_dimension",
                 "replace_attribute_values",
                 when = c("when", "when_available", "when_received", "when_arrived"),
@@ -1063,10 +1184,11 @@ test_that("constellation() replace_attribute_values() with role_playing_dimensio
                 role_playing_dimension(rpd = "When",
                                        roles = c("When Available", "When Received"))
 
-              db2 <- star_database(mrs_age_schema_rpd, ft_age_rpd) |>
+              db2 <-
+                star_database(mrs_age_schema_rpd, ft_age_rpd) |>
                 role_playing_dimension(rpd = "When Arrived",
                                        roles = c("When Available"))
-              db <- constellation("MRS", list(db1, db2))
+              db <- constellation("MRS", db1, db2)
 
               db <- db |> replace_attribute_values(
                 name = "When Available",
@@ -1094,20 +1216,11 @@ test_that("constellation() replace_attribute_values() with role_playing_dimensio
               )
             }, {
               list(
-                "define_dimension",
-                "define_dimension",
-                "define_dimension",
-                "define_dimension",
-                "define_facts",
+                "star_database",
                 "role_playing_dimension",
                 "replace_attribute_values",
                 "group_dimension_instances",
-                "define_dimension",
-                "define_dimension",
-                "define_dimension",
-                "define_dimension",
-                "define_dimension",
-                "define_facts",
+                "star_database",
                 "role_playing_dimension",
                 "replace_attribute_values",
                 "group_dimension_instances",
