@@ -596,9 +596,11 @@ test_that("separate_measures() ", {
           operations = structure(
             list(
               operation = c("flat_table", "separate_measures"),
-              name = c("iris<|>___UNKNOWN___", "Petal.Length"),
-              details = c("Species",
-                          "PL"),
+              name = c(
+                "iris<|>___UNKNOWN___",
+                "Petal.Length<|>Petal.Width<|>Sepal.Length<|>Sepal.Width"
+              ),
+              details = c("Species", "PL<|>PL<|>PW<|>SL<|>SW"),
               details2 = c(
                 "Sepal.Length<|>Sepal.Width<|>Petal.Length<|>Petal.Width",
                 "TRUE"
@@ -632,8 +634,11 @@ test_that("separate_measures() ", {
           operations = structure(
             list(
               operation = c("flat_table", "separate_measures"),
-              name = c("iris<|>___UNKNOWN___", "Petal.Width"),
-              details = c("Species", "PW"),
+              name = c(
+                "iris<|>___UNKNOWN___",
+                "Petal.Length<|>Petal.Width<|>Sepal.Length<|>Sepal.Width"
+              ),
+              details = c("Species", "PW<|>PL<|>PW<|>SL<|>SW"),
               details2 = c(
                 "Sepal.Length<|>Sepal.Width<|>Petal.Length<|>Petal.Width",
                 "TRUE"
@@ -667,8 +672,11 @@ test_that("separate_measures() ", {
           operations = structure(
             list(
               operation = c("flat_table", "separate_measures"),
-              name = c("iris<|>___UNKNOWN___", "Sepal.Length"),
-              details = c("Species", "SL"),
+              name = c(
+                "iris<|>___UNKNOWN___",
+                "Petal.Length<|>Petal.Width<|>Sepal.Length<|>Sepal.Width"
+              ),
+              details = c("Species", "SL<|>PL<|>PW<|>SL<|>SW"),
               details2 = c(
                 "Sepal.Length<|>Sepal.Width<|>Petal.Length<|>Petal.Width",
                 "TRUE"
@@ -702,8 +710,11 @@ test_that("separate_measures() ", {
           operations = structure(
             list(
               operation = c("flat_table", "separate_measures"),
-              name = c("iris<|>___UNKNOWN___", "Sepal.Width"),
-              details = c("Species", "SW"),
+              name = c(
+                "iris<|>___UNKNOWN___",
+                "Petal.Length<|>Petal.Width<|>Sepal.Length<|>Sepal.Width"
+              ),
+              details = c("Species", "SW<|>PL<|>PW<|>SL<|>SW"),
               details2 = c(
                 "Sepal.Length<|>Sepal.Width<|>Petal.Length<|>Petal.Width",
                 "TRUE"
@@ -910,7 +921,7 @@ test_that("join_lookup_table() ", {
         )
       ), class = "star_operation"),
       pk_attributes = "Species",
-      lookup_tables = list(structure(
+      lookup_tables = list(iris = structure(
         list(
           name = "iris",
           table = structure(
@@ -973,6 +984,7 @@ test_that("join_lookup_table() ", {
   ))
 })
 
+
 test_that("check_lookup_table() ", {
   expect_equal({
     lookup <- flat_table('iris', iris) |>
