@@ -1,4 +1,5 @@
 
+
 test_that("star_database() define a a star database", {
   expect_equal({
     s <- star_schema() |>
@@ -22,23 +23,42 @@ test_that("star_database() define a a star database", {
       operations = list(mrs_cause = structure(list(
         operations = structure(
           list(
-            operation = c("define_dimension",
-                          "define_dimension", "define_facts"),
-            name = c("When", "Where",
-                     "MRS Cause"),
-            details = c(
-              "Year",
-              "REGION<|>State",
-              "Pneumonia and Influenza Deaths<|>All Deaths<|>nrow_agg"
-            ),
-            details2 = c("", "", "SUM<|>SUM<|>SUM"),
-            order = c(1,
-                      2, 3)
+            operation = "star_database",
+            name = "mrs_cause",
+            details = "___UNKNOWN___",
+            details2 = "",
+            order = 1
           ),
-          row.names = c(NA,-3L),
+          row.names = c(NA,-1L),
           class = "data.frame"
         )
       ), class = "star_operation")),
+      lookup_tables = list(mrs_cause = NULL),
+      schemas = list(mrs_cause = structure(
+        list(
+          facts = list(mrs_cause = structure(
+            list(
+              name = "MRS Cause",
+              measures = c("Pneumonia and Influenza Deaths",
+                           "All Deaths"),
+              agg_functions = NULL,
+              nrow_agg = NULL
+            ),
+            class = "fact_schema"
+          )),
+          dimensions = list(
+            when = structure(list(
+              name = "When",
+              attributes = "Year"
+            ), class = "dimension_schema"),
+            where = structure(list(
+              name = "Where", attributes = c("REGION",
+                                             "State")
+            ), class = "dimension_schema")
+          )
+        ), class = "star_schema"
+      )),
+      refresh = list(mrs_cause = NULL),
       facts = list(mrs_cause = structure(
         list(
           name = "MRS Cause",
@@ -63,7 +83,7 @@ test_that("star_database() define a a star database", {
             ),
             class = c("tbl_df",
                       "tbl", "data.frame"),
-            row.names = c(NA,-6L)
+            row.names = c(NA, -6L)
           )
         ),
         class = "fact_table"
@@ -78,7 +98,7 @@ test_that("star_database() define a a star database", {
                 when_key = 1:3,
                 Year = c("1962", "1963", "1964")
               ),
-              row.names = c(NA,-3L),
+              row.names = c(NA, -3L),
               class = c("tbl_df",
                         "tbl", "data.frame")
             )
@@ -96,7 +116,7 @@ test_that("star_database() define a a star database", {
                            "1"),
                 State = c("CT", "MA")
               ),
-              row.names = c(NA,-2L),
+              row.names = c(NA, -2L),
               class = c("tbl_df", "tbl", "data.frame")
             )
           ),
@@ -128,18 +148,40 @@ test_that("star_database() define a a star database", {
       operations = list(mrs_cause = structure(list(
         operations = structure(
           list(
-            operation = c("define_dimension",
-                          "define_dimension", "define_facts"),
-            name = c("When", "Where",
-                     "MRS Cause"),
-            details = c("Year", "REGION<|>State", "nrow_agg"),
-            details2 = c("", "", "SUM"),
-            order = c(1, 2, 3)
+            operation = "star_database",
+            name = "mrs_cause",
+            details = "___UNKNOWN___",
+            details2 = "",
+            order = 1
           ),
-          row.names = c(NA,-3L),
+          row.names = c(NA,-1L),
           class = "data.frame"
         )
       ), class = "star_operation")),
+      lookup_tables = list(mrs_cause = NULL),
+      schemas = list(mrs_cause = structure(
+        list(
+          facts = list(mrs_cause = structure(
+            list(
+              name = "MRS Cause",
+              measures = NULL,
+              agg_functions = NULL,
+              nrow_agg = NULL
+            ),
+            class = "fact_schema"
+          )),
+          dimensions = list(
+            when = structure(list(
+              name = "When", attributes = "Year"
+            ), class = "dimension_schema"),
+            where = structure(list(
+              name = "Where", attributes = c("REGION",
+                                             "State")
+            ), class = "dimension_schema")
+          )
+        ), class = "star_schema"
+      )),
+      refresh = list(mrs_cause = NULL),
       facts = list(mrs_cause = structure(
         list(
           name = "MRS Cause",
@@ -156,7 +198,7 @@ test_that("star_database() define a a star database", {
             ),
             class = c("tbl_df",
                       "tbl", "data.frame"),
-            row.names = c(NA,-6L)
+            row.names = c(NA, -6L)
           )
         ),
         class = "fact_table"
@@ -171,7 +213,7 @@ test_that("star_database() define a a star database", {
                 when_key = 1:3,
                 Year = c("1962", "1963", "1964")
               ),
-              row.names = c(NA,-3L),
+              row.names = c(NA, -3L),
               class = c("tbl_df",
                         "tbl", "data.frame")
             )
@@ -189,7 +231,7 @@ test_that("star_database() define a a star database", {
                            "1"),
                 State = c("CT", "MA")
               ),
-              row.names = c(NA,-2L),
+              row.names = c(NA, -2L),
               class = c("tbl_df", "tbl", "data.frame")
             )
           ),
@@ -227,28 +269,44 @@ test_that("snake_case() transform a a star database in snake case", {
       operations = list(mrs_cause = structure(list(
         operations = structure(
           list(
-            operation = c(
-              "define_dimension",
-              "define_dimension",
-              "define_facts",
-              "snake_case"
-            ),
-            name = c("When",
-                     "Where", "MRS Cause", ""),
-            details = c(
-              "Year",
-              "REGION<|>State",
-              "Pneumonia and Influenza Deaths<|>All Deaths<|>nrow_agg",
-              ""
-            ),
-            details2 = c("", "", "SUM<|>SUM<|>SUM", ""),
-            order = c(1,
-                      2, 3, 4)
+            operation = c("star_database",
+                          "snake_case"),
+            name = c("mrs_cause", ""),
+            details = c("___UNKNOWN___",
+                        ""),
+            details2 = c("", ""),
+            order = c(1, 2)
           ),
-          row.names = c(NA,-4L),
+          row.names = c(NA,-2L),
           class = "data.frame"
         )
       ), class = "star_operation")),
+      lookup_tables = list(mrs_cause = NULL),
+      schemas = list(mrs_cause = structure(
+        list(
+          facts = list(mrs_cause = structure(
+            list(
+              name = "MRS Cause",
+              measures = c("Pneumonia and Influenza Deaths",
+                           "All Deaths"),
+              agg_functions = NULL,
+              nrow_agg = NULL
+            ),
+            class = "fact_schema"
+          )),
+          dimensions = list(
+            when = structure(list(
+              name = "When",
+              attributes = "Year"
+            ), class = "dimension_schema"),
+            where = structure(list(
+              name = "Where", attributes = c("REGION",
+                                             "State")
+            ), class = "dimension_schema")
+          )
+        ), class = "star_schema"
+      )),
+      refresh = list(mrs_cause = NULL),
       facts = list(mrs_cause = structure(
         list(
           name = "mrs_cause",
@@ -273,7 +331,7 @@ test_that("snake_case() transform a a star database in snake case", {
             ),
             class = c("tbl_df",
                       "tbl", "data.frame"),
-            row.names = c(NA,-6L)
+            row.names = c(NA, -6L)
           )
         ),
         class = "fact_table"
@@ -288,7 +346,7 @@ test_that("snake_case() transform a a star database in snake case", {
                 when_key = 1:3,
                 year = c("1962", "1963", "1964")
               ),
-              row.names = c(NA,-3L),
+              row.names = c(NA, -3L),
               class = c("tbl_df",
                         "tbl", "data.frame")
             )
@@ -306,7 +364,7 @@ test_that("snake_case() transform a a star database in snake case", {
                            "1"),
                 state = c("CT", "MA")
               ),
-              row.names = c(NA,-2L),
+              row.names = c(NA, -2L),
               class = c("tbl_df", "tbl", "data.frame")
             )
           ),
@@ -333,15 +391,11 @@ test_that("set_attribute_names() and get_attribute_names()",
                   get_attribute_names(name = "where")
               )
             }, {
-              c(
-                "define_dimension",
-                "define_dimension",
-                "define_facts",
+              c("star_database",
                 "set_attribute_names",
                 "Region",
                 "State",
-                "City"
-              )
+                "City")
             })
           })
 
@@ -349,24 +403,22 @@ test_that("set_attribute_names() and get_attribute_names()",
           {
             expect_equal({
               db <- star_database(mrs_cause_schema, ft_num) |>
-                set_attribute_names(name = "where",
-                                    old = c("REGION"),
-                                    new = c("Region"))
+                set_attribute_names(
+                  name = "where",
+                  old = c("REGION"),
+                  new = c("Region")
+                )
               c(
                 db$operations$mrs_cause$operation$operation,
                 db |>
                   get_attribute_names(name = "where")
               )
             }, {
-              c(
-                "define_dimension",
-                "define_dimension",
-                "define_facts",
+              c("star_database",
                 "set_attribute_names",
                 "Region",
                 "State",
-                "City"
-              )
+                "City")
             })
           })
 
@@ -381,9 +433,7 @@ test_that("set_measure_names() and get_measure_names()", {
         get_measure_names())
   }, {
     c(
-      "define_dimension",
-      "define_dimension",
-      "define_facts",
+      "star_database",
       "set_measure_names",
       "Pneumonia and Influenza",
       "All",
@@ -406,7 +456,7 @@ test_that("get_similar_attribute_values()", {
         dput_instance = c("c('1', 'CT', ' BrId  gEport ')",
                           "c('1', 'CT', 'Bridgeport')")
       ),
-      row.names = c(NA, -2L),
+      row.names = c(NA,-2L),
       class = c("tbl_df",
                 "tbl", "data.frame")
     ))
@@ -427,7 +477,7 @@ test_that("get_similar_attribute_values()", {
         dput_instance = c("c('1963')",
                           "c('1963.')")
       ),
-      row.names = c(NA,-2L),
+      row.names = c(NA, -2L),
       class = c("tbl_df", "tbl",
                 "data.frame")
     )),
@@ -439,7 +489,7 @@ test_that("get_similar_attribute_values()", {
         City = c("Bridgeport", " BrId  gEport "),
         dput_instance = c("c('1', ' c   T ', 'Bridgeport')", "c('1', 'CT', ' BrId  gEport ')")
       ),
-      row.names = c(NA,-2L),
+      row.names = c(NA, -2L),
       class = c("tbl_df", "tbl", "data.frame")
     )))
   })
@@ -462,7 +512,7 @@ test_that("get_similar_attribute_values()", {
         dput_instance = c("c(' BrId  gEport ', 'CT')",
                           "c('Bridgeport', ' c   T ')")
       ),
-      row.names = c(NA,-2L),
+      row.names = c(NA, -2L),
       class = c("tbl_df",
                 "tbl", "data.frame")
     ))
@@ -479,18 +529,18 @@ test_that("get_similar_attribute_values_individually()", {
   }, {
     list(when = list(structure(
       list(Year = c("1963", "1963.")),
-      row.names = c(NA,-2L),
+      row.names = c(NA, -2L),
       class = c("tbl_df", "tbl", "data.frame")
     )),
     where = list(
       structure(
         list(State = c(" c   T ", "CT")),
-        row.names = c(NA,-2L),
+        row.names = c(NA, -2L),
         class = c("tbl_df", "tbl", "data.frame")
       ),
       structure(
         list(City = c(" BrId  gEport ", "Bridgeport")),
-        row.names = c(NA,-2L),
+        row.names = c(NA, -2L),
         class = c("tbl_df", "tbl", "data.frame")
       )
     ))
@@ -506,7 +556,7 @@ test_that("get_unique_attribute_values()", {
     list(
       when = structure(
         list(Year = c("1962", "1963", "1964")),
-        row.names = c(NA,-3L),
+        row.names = c(NA, -3L),
         class = c("tbl_df", "tbl", "data.frame")
       ),
       where = structure(
@@ -516,7 +566,7 @@ test_that("get_unique_attribute_values()", {
                     "MA"),
           City = c("Bridgeport", "Hartford", "Boston", "Cambridge")
         ),
-        row.names = c(NA,-4L),
+        row.names = c(NA, -4L),
         class = c("tbl_df", "tbl", "data.frame")
       )
     )
@@ -537,7 +587,7 @@ test_that("get_unique_attribute_values()", {
         City = c("Bridgeport", "Hartford", "Boston",
                  "Cambridge")
       ),
-      row.names = c(NA,-4L),
+      row.names = c(NA, -4L),
       class = c("tbl_df", "tbl",
                 "data.frame")
     )
@@ -553,7 +603,7 @@ test_that("get_unique_attribute_values()", {
   }, {
     structure(
       list(REGION = c("1", "1"), State = c("CT", "MA")),
-      row.names = c(NA,-2L),
+      row.names = c(NA, -2L),
       class = c("tbl_df", "tbl", "data.frame")
     )
   })
@@ -578,7 +628,7 @@ test_that("replace_attribute_values()", {
         City = c("Hartford", "Hartford",
                  "Boston", "Cambridge")
       ),
-      row.names = c(NA, -4L),
+      row.names = c(NA,-4L),
       class = c("tbl_df",
                 "tbl", "data.frame")
     )
@@ -612,11 +662,7 @@ test_that("replace_attribute_values() with role_playing_dimension()", {
     )
   }, {
     list(
-      "define_dimension",
-      "define_dimension",
-      "define_dimension",
-      "define_dimension",
-      "define_facts",
+      "star_database",
       "role_playing_dimension",
       "replace_attribute_values",
       when = c("when", "when_available", "when_received"),
@@ -700,7 +746,7 @@ test_that("as_tibble_list() export star_database as a list of tibbles", {
     list(
       when = structure(
         list(when_key = 1:2, year = c("1962", "1963")),
-        row.names = c(NA, -2L),
+        row.names = c(NA,-2L),
         class = c("tbl_df", "tbl", "data.frame")
       ),
       where = structure(
@@ -711,7 +757,7 @@ test_that("as_tibble_list() export star_database as a list of tibbles", {
                     "CT", "MA"),
           city = c("Bridgeport", "Hartford", "Boston")
         ),
-        row.names = c(NA, -3L),
+        row.names = c(NA,-3L),
         class = c("tbl_df", "tbl", "data.frame")
       ),
       mrs_cause = structure(
@@ -727,7 +773,7 @@ test_that("as_tibble_list() export star_database as a list of tibbles", {
         ),
         class = c("tbl_df",
                   "tbl", "data.frame"),
-        row.names = c(NA, -6L)
+        row.names = c(NA,-6L)
       )
     )
   })
@@ -750,11 +796,7 @@ test_that("role_playing_dimension() define a rpd", {
     )
   }, {
     list(
-      "define_dimension",
-      "define_dimension",
-      "define_dimension",
-      "define_dimension",
-      "define_facts",
+      "star_database",
       "role_playing_dimension",
       when = c("when", "when_available", "when_received"),
       15L,
@@ -797,11 +839,7 @@ test_that("role_playing_dimension() define a rpd", {
     )
   }, {
     list(
-      "define_dimension",
-      "define_dimension",
-      "define_dimension",
-      "define_dimension",
-      "define_facts",
+      "star_database",
       "role_playing_dimension",
       when = c("when", "when_available", "when_received"),
       15L,
@@ -844,11 +882,7 @@ test_that("role_playing_dimension() define a rpd", {
     )
   }, {
     list(
-      "define_dimension",
-      "define_dimension",
-      "define_dimension",
-      "define_dimension",
-      "define_facts",
+      "star_database",
       "role_playing_dimension",
       when = c("when", "when_available", "when_received"),
       15L,
@@ -903,7 +937,7 @@ test_that("as_single_tibble_list()", {
                        192L, 276L),
         nrow_agg = c(3L, 2L, 2L, 1L, 3L, 1L)
       ),
-      row.names = c(NA,-6L),
+      row.names = c(NA, -6L),
       class = c("tbl_df", "tbl", "data.frame")
     ))
   })
@@ -915,7 +949,7 @@ test_that("as_single_tibble_list()", {
       snake_case()
     db2 <- star_database(mrs_age_schema, ft_age) |>
       snake_case()
-    ct <- constellation("MRS", list(db1, db2))
+    ct <- constellation("MRS", db1, db2)
     tl <- ct |>
       as_single_tibble_list()
     c(names(tl$mrs_cause), names(tl$mrs_age))
@@ -1010,7 +1044,7 @@ test_that("as_single_tibble_list()", {
       snake_case()
     db2 <- star_database(mrs_age_schema, ft_age) |>
       snake_case()
-    ct1 <- constellation("MRS", list(db1, db2))
+    ct1 <- constellation("MRS", db1, db2)
     r <- ct1 |> as_single_tibble_list()
     c(names(r[[1]]), names(r[[2]]))
   }, {
